@@ -72,7 +72,7 @@ class AddTagForm(form.EditForm):
                     self.widgets[x].value = tag[x]
                 self.widgets['id'].value = id
 
-    @button.buttonAndHandler(_('Save'), name='save')
+    @button.buttonAndHandler(_(u'Save'), name='save')
     def handleApply(self, action):
         """ Save (create or update) a tag
         """
@@ -123,6 +123,24 @@ class AddTagAjaxForm(AddTagForm):
 
 class AddTagAjaxFormWrapper(AddTagFormWrapper):
     index = ViewPageTemplateFile('templates/form-ajax.pt')
-    #ajax = True
+    
+    def js_vars(self):
+        return """
+        ImageTagsLabels = {
+            tagFormTitle: '%s',
+            removeLinkText: '%s',
+            removeConfirmText: '%s',
+            editLinkText: '%s',
+            yesButtonText: '%s',
+            noButtonText: '%s',
+            saveButtonText: '%s',
+            hyphenLabel: '%s'
+        };
+        """ % (self.form.label, _(u"Remove"), _(u"Are you sure you want to remove this tag?"), \
+               _(u"Edit"), _(u"Yes"), _(u"No"), _(u'Save'), _(u"imagetags.hyphen"))
+        
+class AddTagAjax(FormWrapper):
+    form = AddTagAjaxForm
+    
 
 AddTagAjax = wrap_form(AddTagAjaxForm, __wrapper_class=AddTagAjaxFormWrapper)
